@@ -57,6 +57,7 @@ if TYPE_CHECKING:
             "merged_output": Optional[bool],
             "ignore_unknown_tags": Optional[bool],
             "output_format": Optional[str],
+            "ignore_merged": Optional[bool],
         },
         total=False,
     )
@@ -157,16 +158,27 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             Keyword Arguments:
                 kwargs/merged_output (bool): Output one single merged string
                 kwargs/same_branch (bool): Force searching only in the same branch
+                kwargs/ignore_merged (bool): ignore merged commits
             Returns:
                 the commit message
             """
             current_commit_id = cls.getLast(**kwargs)
             tag_commit_id = cls.getFromTag(tag)
 
+            str_cmd: str
             if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
-                commits = _exec(f"git rev-list --first-parent --ancestry-path {tag_commit_id}..{current_commit_id}")
+                str_cmd = f"git rev-list --first-parent {tag_commit_id}..{current_commit_id}"  # ok
             else:
-                commits = _exec(f"git rev-list --ancestry-path {tag_commit_id}..{current_commit_id}")
+                str_cmd = f"git rev-list {tag_commit_id}..{current_commit_id}"  # ok
+
+            if ("ignore_merged" in kwargs) and (kwargs["ignore_merged"] is True):
+                str_cmd = str_cmd + " --no-merges"  # ok
+
+            try:
+                commits = _exec(str_cmd)
+            except gitversionhelper.unknownGITFatalError as _e:
+                raise cls.commitNotFound("no commit found in commit history") from _e
+
             result = []
             for commit in commits:
                 result.append(cls.getMessage(commit))
@@ -185,7 +197,7 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             """
             try:
                 res = _exec(
-                    f'git log -z --pretty="tformat:%B%-C()" -n 1 {commit_hash}',
+                    f'git log -z --pretty="tformat:%B%-C()" -n 1 {commit_hash}',  # ok
                     None,
                     True,
                 )
@@ -204,9 +216,10 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
                 the commit Id
             """
             try:
-                res = _exec(f"git rev-list -n 1 {tag}")
+                res = _exec(f"git rev-list -n 1 {tag}")  # ok
             except gitversionhelper.unknownGITFatalError as _e:
                 raise cls.commitNotFound("no commit found in commit history") from _e
+
             if len(res) == 0:
                 raise cls.commitNotFound("no commit found in commit history")
             return res[0]
@@ -216,16 +229,23 @@ class gitversionhelper:  # pylint: disable=too-few-public-methods
             """retrieve last commit from repository
             Keyword Arguments:
                 kwargs/same_branch (bool): force searching only in the same branch
+                kwargs/ignore_merged (bool): ignore merged commits
             Returns:
                 the commit Id
             """
+            str_cmd: str
             if ("same_branch" in kwargs) and (kwargs["same_branch"] is True):
-                try:
-                    res = _exec("git rev-parse HEAD")
-                except gitversionhelper.unknownGITFatalError as _e:
-                    raise cls.commitNotFound("no commit found in commit history") from _e
+                str_cmd = "git rev-list --max-count=1 --date-order HEAD --first-parent"  # ok
             else:
-                res = _exec('git for-each-ref --sort=-committerdate refs/heads/ --count 1 --format="%(objectname)"')
+                str_cmd = "git log --format=%H --all -n1"  # ok
+
+            if ("ignore_merged" in kwargs) and (kwargs["ignore_merged"] is True):
+                str_cmd = str_cmd + " --no-merges"  # ok
+
+            try:
+                res = _exec(str_cmd)
+            except gitversionhelper.unknownGITFatalError as _e:
+                raise cls.commitNotFound("no commit found in commit history") from _e
 
             if len(res) == 0:
                 raise cls.commitNotFound("no commit found in commit history")
