@@ -1009,6 +1009,16 @@ class Test_gitversionhelper(unittest.TestCase):
         self.assertEqual(_v.minor, 3)
         self.assertEqual(_v.patch, 0)
 
+        with open("demofile.txt", "w+t") as tmpFile:
+            tmpFile.write("testvalue4")
+        os.system("git add .")
+        os.system('git commit -m  "4th commit"')
+
+        with open("demofile.txt", "w+t") as tmpFile:
+            tmpFile.write("testvalue5")
+        os.system("git add .")
+        os.system('git commit -m  "5th commit"')
+
         os.system("git switch master")
 
         _v = pygitversionhelper.gitversionhelper.version.getLastVersion(version_std="PEP440")
@@ -1404,6 +1414,17 @@ class Test_gitversionhelper(unittest.TestCase):
         cmd = "git commit -m".split()
         cmd.append(commit_message5)
         subprocess.run(cmd, text=True, check=True)
+        os.system(f"git tag 0.1.1.post4")
+
+        commit_message6 = "6.1 update this" + os.linesep + "6.1 fix that" + os.linesep + "6.1 test"
+        commit_message6 = commit_message6.replace("\r\n", "\n").replace("\n", "\r\n")
+        with open("demofile.txt", "w+t") as tmpFile:
+            tmpFile.write("testvalue6")
+        os.system("git add .")
+
+        cmd = "git commit -m".split()
+        cmd.append(commit_message6)
+        subprocess.run(cmd, text=True, check=True)
 
         cmd = "git switch master".split()
         subprocess.run(cmd, text=True, check=True)
@@ -1412,7 +1433,42 @@ class Test_gitversionhelper(unittest.TestCase):
         self.assertEqual(os.linesep.join([commit_message4, commit_message3, commit_message2]), res)
 
         res = pygitversionhelper.gitversionhelper.commit.getMessagesSinceTag("0.1.1", merged_output=True)
-        self.assertEqual(os.linesep.join([commit_message5, commit_message4, commit_message3, commit_message2]), res)
+        self.assertEqual(os.linesep.join([commit_message6, commit_message5, commit_message4, commit_message3, commit_message2]), res)
+
+        time.sleep(1)
+
+        merge_message = "automerge"
+        cmd = "git merge --no-ff dev -m".split()
+        cmd.append(merge_message)
+        subprocess.run(cmd, text=True, check=True)
+
+        res = pygitversionhelper.gitversionhelper.commit.getMessagesSinceTag("0.1.1", merged_output=True, same_branch=True)
+        self.assertEqual(os.linesep.join([merge_message, commit_message4, commit_message3, commit_message2]), res)
+
+        res = pygitversionhelper.gitversionhelper.commit.getMessagesSinceTag("0.1.1", merged_output=True)
+        self.assertEqual(
+            set(
+                merge_message.splitlines()
+                + commit_message6.splitlines()
+                + commit_message5.splitlines()
+                + commit_message4.splitlines()
+                + commit_message3.splitlines()
+                + commit_message2.splitlines()
+            ),
+            set(res.splitlines()),
+        )
+
+        res = pygitversionhelper.gitversionhelper.commit.getMessagesSinceTag("0.1.1", merged_output=True, ignore_merged=True)
+        self.assertEqual(
+            set(
+                commit_message6.splitlines()
+                + commit_message5.splitlines()
+                + commit_message4.splitlines()
+                + commit_message3.splitlines()
+                + commit_message2.splitlines()
+            ),
+            set(res.splitlines()),
+        )
 
     def tearDown(self):
         os.chdir("/")
